@@ -7,9 +7,9 @@ use parent qw/Number::Phone/;
 use utf8;
 use re '/s';
 
-sub AREA_NAMES (); ## no critic (ProhibitSubroutinePrototypes)
+sub AREA_NAMES ();
 
-our $VERSION = '0.002';
+our $VERSION = '1.000';
 
 our %cache;
 
@@ -87,8 +87,8 @@ sub query_portabilitate {
 	$self->_info->{portabilitate_queried} = 1;
 	my $req = $ht->get("http://portabilitate.ro/ro-no-0$$self");
 	return unless $req->{success};
-	my ($initial_operator) = $req->{content} =~ /lnkOperatorInitial">([^<]*)</;
-	my ($current_operator) = $req->{content} =~ /lnkOperator">([^<]*)</;
+	my ($initial_operator) = $req->{content} =~ /lnkOperatorInitial">([^<]*)</x;
+	my ($current_operator) = $req->{content} =~ /lnkOperator">([^<]*)</x;
 	$initial_operator //= $current_operator;
 	$self->_info->{initial_operator} = $initial_operator;
 	$self->_info->{current_operator} = $current_operator;
@@ -192,6 +192,8 @@ following methods from L<Number::Phone> are overridden:
 
 =item B<is_specialrate>
 
+=item B<is_adult>
+
 =item B<country_code>
 
 Always returns 40.
@@ -244,7 +246,7 @@ Marius Gavrilescu, E<lt>marius@ieval.roE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 by Marius Gavrilescu
+Copyright (C) 2015-2016 by Marius Gavrilescu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.20.2 or,
